
/*
It is usual that you receive SQL database from your customer and you cannot login NAV because you haven't got NAV account.

This script assists you to login any NAV systems with SQL database. Same as CRONUS demo system, there is a tip:
  when there is no NAV account, you can login NAV system with your Windows account.

Login information includes below tables:
  NAV 2013 to NAV 2016: [User], [Access Control]
  NAV 2009 and earlier: [User], [Member Of], [Windows Login], [Windows Access Control]

Process follows 3 steps:
  Step1: Backup and clear login information
  Step2: Restart NAV service (if use) with Windows Authentication
	     Login NAV with your Windows account
	     Add your Windows account with SUPER role/permission set
  Step3: Restore login information and clear backup

Author		: 4BzSoftware Team | email: support@4bzsoftware.com | www.4bzsoftware.com
YouTube		: https://www.youtube.com/watch?v=G4UiDyeaiDY&list=PLfgzNr8_2GkpNEHosuTPbbe33PRfBxAwj
Released on	: 2016-10-20
Updated on	: 2016-11-01
*/


--Step1{
---Run script between "--Step1{" and "--Step1}"
---Backup and clear login information

---Backup and clear [User] table
IF OBJECT_ID('[User]', 'U') IS NOT NULL BEGIN
	SELECT *
	INTO [User Backup]
	FROM [User];

	DELETE FROM [User];
END;

---Backup and clear [Access Control] table
IF OBJECT_ID('[Access Control]', 'U') IS NOT NULL BEGIN
	SELECT *
	INTO [Access Control Backup]
	FROM [Access Control];
	
	DELETE FROM [Access Control];
END;

---Backup and clear [Member Of] table
IF OBJECT_ID('[Member Of]', 'U') IS NOT NULL BEGIN
	SELECT *
	INTO [Member Of Backup]
	FROM [Member Of];
	
	DELETE FROM [Member Of];
END;

---Backup and clear [Windows Login] table
IF OBJECT_ID('[Windows Login]', 'U') IS NOT NULL BEGIN
	SELECT *
	INTO [Windows Login Backup]
	FROM [Windows Login];
	
	DELETE FROM [Windows Login];
END;

---Backup and clear [Windows Access Control] table
IF OBJECT_ID('[Windows Access Control]', 'U') IS NOT NULL BEGIN
	SELECT *
	INTO [Windows Access Control Backup]
	FROM [Windows Access Control];
	
	DELETE FROM [Windows Access Control];
END;

--Step1}


--Step2{
---Restart NAV service (if use) with Windows Authentication
---Login NAV with your Windows account
---Add your Windows account with SUPER permission set
--Step2}


--Step3{
---Run script between "--Step3{" and "--Step3}"
---Restore login information and clear backup

DECLARE @ColumnName NVARCHAR(MAX);
DECLARE @SqlCommand NVARCHAR(MAX);

---Restore [User] table and clear backup
IF OBJECT_ID('[User Backup]', 'U') IS NOT NULL BEGIN
	SELECT @ColumnName = (
			SELECT '[' + COLUMN_NAME + '], '
			FROM INFORMATION_SCHEMA.COLUMNS
			WHERE TABLE_NAME = N'User'
				AND COLUMN_NAME <> 'timestamp'
			For XML PATH (''));
	SET @ColumnName = SUBSTRING(@ColumnName, 0, LEN(@ColumnName));
	
	SET @SqlCommand =
		'INSERT INTO [User] (@ColumnName) '
		+ 'SELECT @ColumnName '
		+ 'FROM [User Backup]';
	SET @SqlCommand = REPLACE(@SqlCommand, '@ColumnName', @ColumnName);
	EXEC(@SqlCommand);

	DROP TABLE [User Backup];
END;

---Restore [Access Control] table and clear backup
IF OBJECT_ID('[Access Control Backup]', 'U') IS NOT NULL BEGIN
	SELECT @ColumnName = (
			SELECT '[' + COLUMN_NAME + '], '
			FROM INFORMATION_SCHEMA.COLUMNS
			WHERE TABLE_NAME = N'Access Control'
				AND COLUMN_NAME <> 'timestamp'
			For XML PATH (''));
	SET @ColumnName = SUBSTRING(@ColumnName, 0, LEN(@ColumnName));

	SET @SqlCommand =
		'INSERT INTO [Access Control] (@ColumnName) '
		+ 'SELECT @ColumnName '
		+ 'FROM [Access Control Backup]';
	SET @SqlCommand = REPLACE(@SqlCommand, '@ColumnName', @ColumnName);
	EXEC(@SqlCommand);

	DROP TABLE [Access Control Backup];
END;

---Restore [Member Of]  table and clear backup
IF OBJECT_ID('[Member Of Backup]', 'U') IS NOT NULL BEGIN
	SELECT @ColumnName = (
			SELECT '[' + COLUMN_NAME + '], '
			FROM INFORMATION_SCHEMA.COLUMNS
			WHERE TABLE_NAME = N'Member Of'
				AND COLUMN_NAME <> 'timestamp'
			For XML PATH (''));
	SET @ColumnName = SUBSTRING(@ColumnName, 0, LEN(@ColumnName));

	SET @SqlCommand =
		'INSERT INTO [Member Of] (@ColumnName) '
		+ 'SELECT @ColumnName '
		+ 'FROM [Member Of Backup]';
	SET @SqlCommand = REPLACE(@SqlCommand, '@ColumnName', @ColumnName);
	EXEC(@SqlCommand);

	DROP TABLE [Member Of Backup];
END;

---Restore [Windows Login] table and clear backup
IF OBJECT_ID('[Windows Login Backup]', 'U') IS NOT NULL BEGIN
	SELECT @ColumnName = (
			SELECT '[' + COLUMN_NAME + '], '
			FROM INFORMATION_SCHEMA.COLUMNS
			WHERE TABLE_NAME = N'Windows Login'
				AND COLUMN_NAME <> 'timestamp'
			For XML PATH (''));
	SET @ColumnName = SUBSTRING(@ColumnName, 0, LEN(@ColumnName));

	SET @SqlCommand =
		'INSERT INTO [Windows Login] (@ColumnName) '
		+ 'SELECT @ColumnName '
		+ 'FROM [Windows Login Backup]';
	SET @SqlCommand = REPLACE(@SqlCommand, '@ColumnName', @ColumnName);
	EXEC(@SqlCommand);

	DROP TABLE [Windows Login Backup];
END;

---Restore [Windows Access Control] table and clear backup
IF OBJECT_ID('[Windows Access Control Backup]', 'U') IS NOT NULL BEGIN
	SELECT @ColumnName = (
			SELECT '[' + COLUMN_NAME + '], '
			FROM INFORMATION_SCHEMA.COLUMNS
			WHERE TABLE_NAME = N'Windows Access Control'
				AND COLUMN_NAME <> 'timestamp'
			For XML PATH (''));
	SET @ColumnName = SUBSTRING(@ColumnName, 0, LEN(@ColumnName));

	SET @SqlCommand =
		'INSERT INTO [Windows Access Control] (@ColumnName) '
		+ 'SELECT @ColumnName '
		+ 'FROM [Windows Access Control Backup]';
	SET @SqlCommand = REPLACE(@SqlCommand, '@ColumnName', @ColumnName);
	EXEC(@SqlCommand);

	DROP TABLE [Windows Access Control Backup];
END;

--Step3}
